@@ -4,10 +4,9 @@ globalVariables(".data")
 #'
 #' This package provides API access to data from the US
 #' \href{https://www.eia.gov/}{Energy Information Administration} (EIA).
-#' @docType package
 #' @name eia
 #' @aliases eia-package
-NULL
+"_PACKAGE"
 
 #' @importFrom tibble tibble
 NULL
